<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:saxon="http://icl.com/saxon" extension-element-prefixes="saxon"
    xmlns:rdf="http://www.w3.org/TR/REC-rdf-syntax#"
    xmlns:dc="http://purl.org/dc/">

  <xsl:template match="p">
    <p><xsl:apply-templates/></p>
  </xsl:template>

  <xsl:template match="dl">
    <dl><xsl:value-of select="."/></dl>
  </xsl:template>

  <xsl:template match="dt">
    <dt><xsl:value-of select="."/></dt>
  </xsl:template>
  
  <xsl:template match="dd">
    <dd><xsl:value-of select="."/></dd>
  </xsl:template>

  <xsl:template match="ul">
    <ul><xsl:value-of select="."/></ul>
  </xsl:template>

  <xsl:template match="ol">
    <ol><xsl:apply-templates/></ol>
  </xsl:template>
  
  <xsl:template match="li">
    <li><xsl:value-of select="."/></li>
  </xsl:template>

  <xsl:template match="sub_section">
    <h3><xsl:value-of select="title"/></h3>
    <xsl:apply-templates/>
  </xsl:template>
  
  <xsl:template match="title"/>
  
  <xsl:template match="img">
    <img src="{@src}"/>
  </xsl:template>
  
  <xsl:template match="warning">
    <table width="80%" align="center" bgcolor="red" class="WARNING">
      <caption>WARNING</caption>
      <tr><td><xsl:apply-templates/></td></tr>
    </table>
  </xsl:template>
  
  <xsl:template match="note">
    <table border="1">
      <tr><td><b>NOTE:</b> <xsl:apply-templates/></td></tr>
    </table>  
  </xsl:template>

  <xsl:template match="caution">
    <table width="80%" align="center" bgcolor="yellow" class="CAUTION">
      <caption>CAUTION</caption>
      <tr><td><xsl:apply-templates/></td></tr>
    </table>
  </xsl:template>

	<!--
	    
	  -->
	<xsl:template match="product_info">
	  <table>
	    <caption><b>Product Information</b></caption>
	    <tr>
	      <td align="right"><b>Company:</b></td><td><a href="{manufacturer/web_site}"><xsl:value-of select="manufacturer/company_name"/></a></td>
	    </tr>
	    <tr>
	      <td align="right"><b>Product Type:</b></td><td><xsl:value-of select="product_type"/></td>
	    </tr>
	    <tr>
	      <td align="right"><b>Model Number:</b></td><td><xsl:value-of select="model_num"/></td>
	    </tr>
	  </table>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="manufacturer">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="company_name">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="web_site">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="product_type">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="model_num">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="rdf:RDF">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="rdf:Description">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="dc:creator">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="dc:description">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="dc:date">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="body">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="fcc_info">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="fcc_warning">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="fcc_sticker">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="fcc_id">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="origin">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="compliance">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="emph">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="features">
		<h3>Product features:</h3>
		<ul>
		  <xsl:apply-templates/>
		</ul>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="feature">
		<li><xsl:value-of select="@name"/></li>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="accessories">
		<table border="1">
		  <tr>
		    <xsl:apply-templates select="accessory" mode="label"/>
		  </tr>
		  <tr>
		    <xsl:apply-templates select="accessory" mode="picture"/>
		  </tr>
		</table>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="accessory" mode="label">
		<td><xsl:apply-templates/></td>
	</xsl:template>

	<xsl:template match="accessory" mode="picture">
		<td><img src="{@picture}" alt="{.}"/></td>
	</xsl:template>
	
	<xsl:template match="accessory">
	  <p><xsl:value-of select="desc"/><font size="-1">(
	    <xsl:value-of select="manufacturer"/>)</font></p>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="safeguards">
		<table>
		  <xsl:apply-templates/>
		</table>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="safeguard">
	  <tr>
	    <!--<td valign="top" rowspan="2"><b><xsl:number/>)</b></td>-->
	    <td valign="top" rowspan="2"><b><xsl:value-of select="position()"/>)</b></td>
	    <td><font size="+2"><b><xsl:value-of select="@desc"/></b></font></td>
	  </tr>
	  <tr>
	    <td><blockquote><xsl:apply-templates/></blockquote></td>
	  </tr>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="exception">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="figure">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="diagram">
		<img src="{@src}" alt="{@title}"/>
		<h3><xsl:value-of select="@title"/></h3>
		<table>
		  <xsl:apply-templates/>
		</table>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="callout">
		<tr>
		  <td valign="top" align="left" rowspan="2"><b><xsl:value-of select="@label"/></b></td>
		  <td><b><xsl:value-of select="@desc"/></b></td>
		</tr>
		<tr>
		  <td><xsl:apply-templates/></td>
		</tr>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="desc">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="type_num">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="process">
	  <h3><xsl:value-of select="@title"/></h3>
	  <h4><xsl:value-of select="@desc"/></h4>
	  <table>
		  <xsl:apply-templates/>
		</table>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="step">
	  <tr>
	    <td valign="top"><xsl:number/>)</td><td><xsl:apply-templates mode="step"/></td>
	  </tr>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="cautions">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="notes">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="precaution">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="table">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="tr">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="td">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="precautions">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="troubles">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="trouble">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="symptom">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="actions">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="action">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="specs">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="spec">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="type">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="value">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="warranty">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="period">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="item">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="labor">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="parts">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="service_type">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="exclusions">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="exclusion">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="requirements">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="proof">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="registration">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="service">
		<xsl:apply-templates/>
	</xsl:template>

	<!--
	    
	  -->
	<xsl:template match="support">
		<xsl:apply-templates/>
	</xsl:template>
</xsl:stylesheet>
