Attribute VB_Name = "TaskBarSupport"
Option Explicit

' Windows API declarations
Public Declare Function SetWindowLongA Lib "user32" (ByVal hwnd As Long, ByVal nIndex As Long, ByVal dwNewLong As Long) As Long
Public Declare Function CallWindowProcA Lib "user32" (ByVal lpPrevWndFunc As Long, ByVal hwnd As Long, ByVal Msg As Long, ByVal wParam As Long, ByVal lParam As Long) As Long
Public Declare Function Shell_NotifyIconA Lib "shell32.dll" (ByVal dwMessage As Long, lpData As NOTIFYICONDATA) As Long

Public Type NOTIFYICONDATA

  cbSize As Long           ' size of the structure
  hwnd As Long             ' the handle of the window
  uID As Long              ' an unique ID for the icon
  uFlags As Long           ' flags(see below)
  uCallbackMessage As Long ' the Msg that call back when a user do something to the icon
  hIcon As Long            ' the memory location of the icon
  szTip As String * 64     ' tooltip max 64 characters

End Type

Public Const NIM_ADD = &H0      ' add an icon to the system tray
Public Const NIM_MODIFY = &H1   ' modify an icon in the system tray
Public Const NIM_DELETE = &H2   ' delete an icon in the system tray
Public Const NIF_MESSAGE = &H1  ' whether a message is sent to the window procedure for events
Public Const NIF_ICON = &H2     ' whether an icon is displayed
Public Const NIF_TIP = &H4      ' tooltip availibility

Public Const WM_USER = &H400
Public Const WM_RBUTTONUP = &H205
Public Const WM_LBUTTONDBLCLK = &H203

Public Declare Function ShowWindow Lib "user32" (ByVal hwnd As Long, ByVal nCmdShow As Long) As Long
Public Const SW_NORMAL = 1

' local declarations
Private procOld As Long
Public frmTB As Form
Public mnuShow As Menu
Const WM_TB_NOTIFY = WM_USER + 1

Public Function procTaskBar&(ByVal hwnd As Long, ByVal Msg As Long, ByVal wParam As Long, ByVal lParam As Long)
  Select Case Msg
  Case WM_TB_NOTIFY
    Select Case lParam
    Case WM_RBUTTONUP
      frmMain.PopupMenu frmMain.mnuTaskBar
    Case WM_LBUTTONDBLCLK
      If Not frmMain.Visible Then
        frmMain.Show
      End If
    End Select
  End Select
  
  procTaskBar = CallWindowProcA(procOld, hwnd, Msg, wParam, lParam)
End Function

Public Sub AddToTaskBar(frmAdd As Form, strTip As String)
  Dim nid As NOTIFYICONDATA

  Set frmTB = frmAdd
  
  With nid
    .cbSize = Len(nid) ' size of this structure
    .hwnd = frmTB.hwnd ' memory location(handle) for the processor of its message and icon
    .uID = 0 ' the unique ID for the icon. must be different from the other sys tray icon
    .uFlags = NIF_MESSAGE Or NIF_ICON Or NIF_TIP ' notify of message, display icon, display tooltip
    .uCallbackMessage = WM_TB_NOTIFY ' message used to be notified when there's event. any number greater than 1300 will do
    .hIcon = frmTB.Icon      ' assign the icon to the form's icon
    .szTip = strTip & vbNullChar ' terminate the string with vbNullChar or Chr(0)
  End With

  ' Shell_NotifyIconA ID_OF_ICON, NOTIFYICONDATA
  Shell_NotifyIconA NIM_ADD, nid

  ' oldproc is the address(memory location) of the original window procedure
  procOld = SetWindowLongA(frmTB.hwnd, -4, AddressOf procTaskBar)
End Sub

Public Sub RemoveFromTaskBar()
  Dim nid As NOTIFYICONDATA

  With nid
    .hwnd = frmTB.hwnd
    .cbSize = Len(nid) ' size of structure
    .uID = 0 ' the id we set earlier
  End With

  ' delete the icon!
  Shell_NotifyIconA NIM_DELETE, nid
  ' set the window procedure back to the original
  ' otherwise if stop using the vb stop button, it will crash
  ' usually won't be a big problem, because mine has crash many times

  SetWindowLongA frmTB.hwnd, -4, procOld
End Sub

Public Sub UpdateTaskBar(strTip As String)
  Dim nid As NOTIFYICONDATA

  With nid
    .cbSize = Len(nid) ' size of this structure
    .hwnd = frmTB.hwnd ' memory location(handle) for the processor of its message and icon
    .uID = 0 ' the unique ID for the icon. must be different from the other sys tray icon
    .uFlags = NIF_MESSAGE Or NIF_ICON Or NIF_TIP ' notify of message, display icon, display tooltip
    .uCallbackMessage = WM_TB_NOTIFY ' message used to be notified when there's event. any number greater than 1300 will do
    .hIcon = frmTB.Icon      ' assign the icon to the form's icon
    .szTip = strTip & vbNullChar ' terminate the string with vbNullChar or Chr(0)
  End With

  ' Shell_NotifyIconA ID_OF_ICON, NOTIFYICONDATA
  If Shell_NotifyIconA(NIM_MODIFY, nid) = 0 Then
    Shell_NotifyIconA NIM_ADD, nid
  End If
End Sub
