
/**
 * Title:        Remote Order Client<p>
 * Description:  This is a simple Java client that illustrates how XML can be used
 * to transmit order information using email.<p>
 * Copyright:    Copyright (c) W. Scott Means<p>
 * Company:      Sams' Strategic XML<p>
 * @author W. Scott Means
 * @version 1.0
 */
package com.strategicxml.examples.OrderClient;

import java.awt.*;
import java.util.*;
import java.io.*;

import java.awt.event.*;
import javax.swing.*;

import org.jdom.*;
import org.jdom.input.*;
import org.jdom.output.*;

import org.gjt.fredde.util.net.Smtp;

public class OrderFrame extends JFrame {
  JPanel contentPane;
  JMenuBar menuBar1 = new JMenuBar();
  JMenu menuFile = new JMenu();
  JMenuItem menuFileExit = new JMenuItem();
  JMenu menuHelp = new JMenu();
  JMenuItem menuHelpAbout = new JMenuItem();
  JLabel statusBar = new JLabel();
  BorderLayout borderLayout1 = new BorderLayout();
  JPanel jPanel1 = new JPanel();
  JLabel lblCatalog = new JLabel();
  JList lstCatalog = new JList();
  JLabel lblQuantity = new JLabel();
  JTextField txtQuantity = new JTextField();
  JButton btnAdd = new JButton();
  JTable tabOrder = new JTable();
  JLabel lblOrder = new JLabel();
  JButton btnXmit = new JButton();

  private static final String DEFAULT_SAX_DRIVER_CLASS =
      "org.apache.xerces.parsers.SAXParser";

  private SAXBuilder m_bBuilder;
  Document m_docCatalog;
  Document m_docOrder;

  private static final String DEF_CONFIG_FILE_NAME = "OrderClientConfig.xml";
  Document m_docAppConfig;
  JButton btnClearOrder = new JButton();
  JLabel jLabel1 = new JLabel();
  JLabel jLabel2 = new JLabel();
  JTextField txtCustName = new JTextField();
  JTextField txtCreditCardNum = new JTextField();
  JLabel jLabel3 = new JLabel();

  //Construct the frame
  public OrderFrame(String [] args) {
    enableEvents(AWTEvent.WINDOW_EVENT_MASK);
    try {
      jbInit();

      // create a new JDOM SAXBuilder instance, using the default SAX driver
      // class (in this application, the default is the Apache Xerces parser)
      m_bBuilder = new SAXBuilder(DEFAULT_SAX_DRIVER_CLASS);

      if (args.length > 0) {
        m_docAppConfig = m_bBuilder.build(args[0]);
      } else {
        m_docAppConfig = m_bBuilder.build(DEF_CONFIG_FILE_NAME);
      }

      String strCatURL;

      if (args.length > 1) {
        strCatURL = args[1];
      } else {
        strCatURL = m_docAppConfig.getRootElement()
            .getChild("catalog_url").getText();
      }

      loadCatalog(strCatURL);

      resetOrder();
    }
    catch(Exception e) {
      e.printStackTrace();
    }
  }

  public void resetOrder()
  {
    // create a new order document object
    Element elRoot = new Element("order");
    m_docOrder = new Document(elRoot);

    // create the empty structure of the order document
    elRoot.addContent(new Element("customer_name"));
    elRoot.addContent(new Element("credit_card_num"));
    elRoot.addContent(new Element("items"));

    // set up the on-screen order table with a new table model
    OrderTableModel otm = new OrderTableModel(m_docOrder);

    tabOrder.setModel(otm);

    // reset the other text controls
    txtCustName.setText("");
    txtCreditCardNum.setText("");
    txtQuantity.setText("1");
  }

  public void loadCatalog(String strCatalogURL) throws Exception
  {
    // parse the product catalog
    m_docCatalog = m_bBuilder.build(strCatalogURL);


    // init UI with catalog info

    // first, get a list of all of the item elements in the catalog
    Element elCat = m_docCatalog.getRootElement();
    Element elItems = elCat.getChild("items");

    java.util.List lstItems = elItems.getChildren("item");

    // now, populate a Vector with text descriptions of each item
    Vector vItems = new Vector();
    Iterator i = lstItems.iterator();
    Element e;

    while (i.hasNext()) {
      e = (Element)i.next();

      vItems.add(e.getChildText("desc") + " ("
          + e.getAttributeValue("part_num") + ")");
    }

    // now initialize the listbox with the list of items
    lstCatalog.setListData(vItems);
  }

  //Component initialization
  private void jbInit() throws Exception  {
    contentPane = (JPanel) this.getContentPane();
    contentPane.setLayout(borderLayout1);
    this.setSize(new Dimension(400, 350));
    this.setTitle("Remote Order GUI");
    this.setResizable(false);
    statusBar.setText(" ");
    menuFile.setText("File");
    menuFileExit.setText("Exit");
    menuFileExit.addActionListener(new ActionListener()  {

      public void actionPerformed(ActionEvent e) {
        fileExit_actionPerformed(e);
      }
    });
    menuHelp.setText("Help");
    menuHelpAbout.setText("About");
    menuHelpAbout.addActionListener(new ActionListener()  {

      public void actionPerformed(ActionEvent e) {
        helpAbout_actionPerformed(e);
      }
    });
    jPanel1.setLayout(null);
    lblCatalog.setText("1) Choose a product:");
    lblCatalog.setBounds(new Rectangle(7, 2, 123, 19));
    lstCatalog.setBounds(new Rectangle(6, 25, 195, 179));
    lblQuantity.setText("2) Enter a quantity:");
    lblQuantity.setBounds(new Rectangle(6, 217, 111, 17));
    txtQuantity.setText("1");
    txtQuantity.setBounds(new Rectangle(120, 210, 80, 27));
    btnAdd.setActionCommand("btnAdd");
    btnAdd.setText("3) Add to Order");
    btnAdd.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        btnAdd_actionPerformed(e);
      }
    });
    btnAdd.setBounds(new Rectangle(5, 241, 194, 37));
    tabOrder.setBounds(new Rectangle(221, 24, 169, 97));
    lblOrder.setText("Current order:");
    lblOrder.setBounds(new Rectangle(219, 5, 167, 18));
    btnXmit.setText("4) Transmit Order!");
    btnXmit.setBounds(new Rectangle(220, 208, 172, 35));
    btnXmit.addActionListener(new ActionListener()  {

      public void actionPerformed(ActionEvent e) {
        btnXmit_actionPerformed(e);
      }
    });
    btnClearOrder.setToolTipText("");
    btnClearOrder.setText("Clear Order!");
    btnClearOrder.setBounds(new Rectangle(220, 245, 173, 34));
    btnClearOrder.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        btnClearOrder_actionPerformed(e);
      }
    });
    jLabel1.setText("3) Enter customer info.:");
    jLabel1.setBounds(new Rectangle(221, 129, 169, 18));
    jLabel2.setText("Name:");
    jLabel2.setBounds(new Rectangle(221, 151, 38, 18));
    txtCustName.setBounds(new Rectangle(262, 150, 125, 27));
    txtCreditCardNum.setBounds(new Rectangle(263, 179, 125, 27));
    jLabel3.setBounds(new Rectangle(221, 183, 38, 18));
    jLabel3.setText("CCN:");
    menuFile.add(menuFileExit);
    menuHelp.add(menuHelpAbout);
    menuBar1.add(menuFile);
    menuBar1.add(menuHelp);
    this.setJMenuBar(menuBar1);
    contentPane.add(statusBar, BorderLayout.SOUTH);
    contentPane.add(jPanel1, BorderLayout.CENTER);
    jPanel1.add(lstCatalog, null);
    jPanel1.add(lblCatalog, null);
    jPanel1.add(btnAdd, null);
    jPanel1.add(txtQuantity, null);
    jPanel1.add(lblQuantity, null);
    jPanel1.add(tabOrder, null);
    jPanel1.add(lblOrder, null);
    jPanel1.add(btnXmit, null);
    jPanel1.add(btnClearOrder, null);
    jPanel1.add(jLabel1, null);
    jPanel1.add(jLabel2, null);
    jPanel1.add(txtCustName, null);
    jPanel1.add(txtCreditCardNum, null);
    jPanel1.add(jLabel3, null);
  }

  //File | Exit action performed
  public void fileExit_actionPerformed(ActionEvent e) {
    System.exit(0);
  }

  //Help | About action performed
  public void helpAbout_actionPerformed(ActionEvent e) {
    OrderFrame_AboutBox dlg = new OrderFrame_AboutBox(this);
    Dimension dlgSize = dlg.getPreferredSize();
    Dimension frmSize = getSize();
    Point loc = getLocation();
    dlg.setLocation((frmSize.width - dlgSize.width) / 2 + loc.x, (frmSize.height - dlgSize.height) / 2 + loc.y);
    dlg.setModal(true);
    dlg.show();
  }

  public void btnAdd_actionPerformed(ActionEvent e) {
    if (lstCatalog.getSelectedValue() == null) {
      return;
    }
    // add the currently selected item to the order
    String strItem = (String)lstCatalog.getSelectedValue();

    // find the part #
    int iStart = strItem.lastIndexOf('(');
    if (iStart < 0) {
      // internal error, malformed item string
      return;
    }

    iStart++;

    int iEnd = strItem.lastIndexOf(')');

    String strPartNum;
    if (iEnd < 0) {
      strPartNum = strItem.substring(iStart);
    } else {
      strPartNum = strItem.substring(iStart, --iEnd);
    }

    ((OrderTableModel)tabOrder.getModel()).addPartToOrder(strPartNum,
        txtQuantity.getText());
  }

  public void btnClearOrder_actionPerformed(ActionEvent e) {
    resetOrder();
  }

  public void btnXmit_actionPerformed(ActionEvent e) {
    // update the order document
    Element elOrder = m_docOrder.getRootElement();

    elOrder.getChild("customer_name").setText(txtCustName.getText());
    elOrder.getChild("credit_card_num").setText(txtCreditCardNum.getText());

    // find out how to order the selected items
    Element elOrderInfo = m_docCatalog.getRootElement().getChild("order_info");

    String strOrderMethod = elOrderInfo.getAttributeValue("method");

    if (strOrderMethod.equals("email")) {
      statusBar.setText("Attempting to email order...");
      if (!sendEmailOrder(elOrderInfo.getAttributeValue("address"))) {
        statusBar.setText("Email order transmission failed!");
      } else {
        statusBar.setText("Email order successful.");

        // order sent, so clear and prepare for another order
        resetOrder();
      }
    }
  }

  protected boolean sendEmailOrder(String strDestAddress) {
    try {
      // send the current order as an XML email message

      // note that this simple SMTP implementation requires that the various
      // methods be called in exactly the order given (to conform to the SMTP
      // RFC.)
      Smtp smtp = new Smtp(m_docAppConfig.getRootElement()
          .getChild("smtp_server").getText());

      // get the salesman's email address
      Element elSalesman = m_docAppConfig.getRootElement().getChild("salesman");

      smtp.from(elSalesman.getChild("email").getText());

      smtp.to(strDestAddress);

      PrintWriter pwOut = smtp.getOutputStream();

      pwOut.println("Subject: Another order from " + elSalesman
          .getChild("name").getText());

      pwOut.println();

      XMLOutputter xo = new XMLOutputter();

      xo.output(m_docOrder, pwOut);

      smtp.sendMessage();

      smtp.close();

      return true;
    } catch (IOException ioe) {
      return false;
    }
  }

  //Overridden so we can exit when window is closed
  protected void processWindowEvent(WindowEvent e) {
    super.processWindowEvent(e);
    if (e.getID() == WindowEvent.WINDOW_CLOSING) {
      fileExit_actionPerformed(null);
    }
  }
}